@@ -68,7 +68,7 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
             args_api=args_api,
             date_modified_from=date_modified_from,
             batch_api=batch_api,
-            is_oauth2=is_oauth2,
+            is_oauth2=is_oauth2
         )
 
         self.logger = logging.getLogger(__class__.__name__)
@@ -88,10 +88,16 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
             if self.date_modified_from is not None:
                 self.logger.info("Uploading data with after %s ", self.date_modified_from)
                 if url_base.find('only_deleted') == -1:
-                    params["filter[updated_at][from]"] = int(
+                    if self.entity != 'events':
+                        field_with_offset = 'updated_at'
+                    else:
+                        field_with_offset = 'created_at'
+
+                    params[f"filter[{field_with_offset}][from]"] = int(
                         self.date_modified_from.timestamp()
                     )
             has_next = True
+
             while has_next and cur_page < PAGE_NUMBER_MAX:
                 self.logger.info("Extracting page №%d", cur_page)
 
@@ -114,6 +120,7 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
                     break
 
                 limit_from_url = get_limit_from_url(objects)
+
                 if "next" not in objects.json()["_links"]:
                     has_next = False
 
